<?php
/**
 * {SYL_CLASS} 饹
 *
 * @access    public
 * @package   {APP_NAME}
 * @author    {author}
 * @copyright {copyright}
 * @version   $Id: action.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
 */
class {SYL_CLASS} extends AppAction
{
    /**
     * ǥեȥ
     *
     * @access public
     * @param object ǡ֥
     * @param object ƥȴ֥
     * @return void
     */
    function execute(&$data, &$context)
    {
        /*
         *  ѥ᡼μ
         * $example = $data->get('example');
         *
         *  ѥ᡼Υåȡʥӥ塼ƥץ졼ȤͤϤ
         * $data->set('example', $example);
         */
    }

}

?>
